@@ -16,11 +16,11 @@
 
 //! Implementation of a node in Abstract Syntax Tree for `FEEL` grammar.
 
-use {
-  crate::{types::FeelType, Name, Scope},
-  dmntk_common::Stringify,
-  std::{borrow::Borrow, str::FromStr},
-};
+use crate::types::FeelType;
+use crate::{Name, Scope};
+use dmntk_common::Stringify;
+use std::borrow::Borrow;
+use std::str::FromStr;
 
 /// Type for optional AST node.
 pub type OptAstNode = Option<AstNode>;
