@@ -21,11 +21,9 @@ use crate::names::{Name, QualifiedName};
 use crate::types::FeelType;
 use crate::values::Value;
 use dmntk_common::{DmntkError, Feelify, Jsonify, Stringify};
-use std::{
-  collections::{BTreeMap, HashSet},
-  convert::TryFrom,
-  ops::Deref,
-};
+use std::collections::{BTreeMap, HashSet};
+use std::convert::TryFrom;
+use std::ops::Deref;
 
 /// Type alias for context entries.
 type FeelContextEntries = BTreeMap<Name, Value>;
@@ -245,10 +243,8 @@ impl FeelContext {
 
 /// Definitions of context errors.
 pub mod errors {
-  use {
-    crate::values::Value,
-    dmntk_common::{DmntkError, Feelify},
-  };
+  use crate::values::Value;
+  use dmntk_common::{DmntkError, Feelify};
 
   /// Context errors.
   #[derive(Debug, PartialEq)]
@@ -283,8 +279,7 @@ mod tests {
   use crate::context::FeelContext;
   use crate::names::{Name, QualifiedName};
   use crate::values::Value;
-  use dmntk_common::Feelify;
-  use dmntk_common::Jsonify;
+  use dmntk_common::{Feelify, Jsonify};
 
   #[test]
   fn test_context_default() {
