@@ -14,7 +14,10 @@
 
 //! `FEEL` years and months durations.
 
-use {self::errors::*, dmntk_common::DmntkError, regex::Regex, std::convert::TryFrom};
+use self::errors::*;
+use dmntk_common::DmntkError;
+use regex::Regex;
+use std::convert::TryFrom;
 
 /// Regular expression pattern for parsing years and months duration.
 const REGEX_YEARS_AND_MONTHS: &str = r#"^(?P<sign>-)?P((?P<years>[0-9]+)Y)?((?P<months>[0-9]+)M)?$"#;
@@ -155,10 +158,8 @@ pub mod errors {
 
 #[cfg(test)]
 mod tests {
-  use {
-    super::{FeelYearsAndMonthsDuration, MONTHS_IN_YEAR},
-    std::convert::{TryFrom, TryInto},
-  };
+  use super::{FeelYearsAndMonthsDuration, MONTHS_IN_YEAR};
+  use std::convert::{TryFrom, TryInto};
 
   /// Utility function for testing years and months durations equality.
   fn equals(months: i64, text: &str) {
