@@ -25,10 +25,8 @@ use crate::temporal::dt_duration::FeelDaysAndTimeDuration;
 use crate::temporal::ym_duration::FeelYearsAndMonthsDuration;
 use crate::temporal::{FeelDateTime, FeelTime};
 use crate::types::FeelType;
-use dmntk_common::errors::Result;
-use dmntk_common::feelify::Feelify;
-use dmntk_common::jsonify::Jsonify;
-use dmntk_common::null_with_trace;
+use crate::AstNode;
+use dmntk_common::{null_with_trace, Feelify, Jsonify, Result, Stringify};
 use std::collections::BTreeMap;
 use std::convert::TryFrom;
 use std::ops::Deref;
@@ -54,7 +52,7 @@ pub enum FunctionBody {
   /// Function body created from model context.
   // Context(Context),
   /// Function body created from `FEEL` textual representation.
-  // LiteralExpression(AstNode),
+  LiteralExpression(AstNode),
   /// Function body created from decision table.
   /// DecisionTable(DecisionTable),
   /// Function body is defined as a call to an externally defined function,
@@ -68,78 +66,120 @@ pub enum FunctionBody {
 pub enum Value {
   /// Value representing `FEEL` boolean type.
   Boolean(bool),
+
   /// Value for storing built-in function definition.
   BuiltInFunction(Bif),
+
   /// Value for storing built-in type definition.
   BuiltInType(FeelType),
+
   /// Value for storing a collection of values representing a comma-separated list of values.
   CommaList(Values),
+
   /// Value representing a context.
   Context(FeelContext),
+
   /// Value representing a context entry.
   ContextEntry(Name, Box<Value>),
+
   /// Value representing a key of the context entry.
   ContextEntryKey(Name),
+
   /// Value representing a name of the context entry in context type definition.
   ContextEntryName(Name),
+
   /// Value for storing dates as [FeelDate].
   Date(FeelDate),
+
   /// Value for storing date and time as [FeelDateTime].
   DateTime(FeelDateTime),
+
   /// Value for days and time durations.
   DaysAndTimeDuration(FeelDaysAndTimeDuration),
+
   /// Value representing function's formal parameter with name and type.
   FormalParameter(Name, FeelType),
+
   /// List of formal parameters.
   FormalParameters(Vec<(Name, FeelType)>),
+
   /// Definition of the function body.
   FunctionBody(FunctionBody),
-  /// Value representing function definition; (formal parameters, function body, result type).
-  FunctionDefinition(Vec<(Name, FeelType)>, FunctionBody, FeelType),
+
+  /// Value representing the function definition.
+  /// This value holds the list of function's formal parameters, and the function's body.
+  FunctionDefinition(Vec<(Name, FeelType)>, FunctionBody),
+
   /// Value representing interval end.
   IntervalEnd(Box<Value>, bool),
+
   /// Value representing interval start.
   IntervalStart(Box<Value>, bool),
+
   /// **Irrelevant** value...
   Irrelevant,
+
   /// Value representing a list of values.
   List(Values),
+
   /// Named parameter.
   NamedParameter(Box<Value>, Box<Value>),
+
   /// Value representing a collection of name parameters.
   NamedParameters(BTreeMap<Name, Value>),
+
   /// **NegatedCommaList** value...
   NegatedCommaList(Vec<Value>),
+
   /// Null value with optional tracing message.
   Null(Option<String>),
+
   /// Numeric value
   Number(f64),
+
   /// Name of the parameter.
   ParameterName(Name),
+
   /// List of positional parameters.
   PositionalParameters(Vec<Value>),
+
   /// Value representing a `range`.
   Range(Box<Value>, bool, Box<Value>, bool),
+
   /// **String** value...
   String(String),
+
   /// Value for storing time as [FeelTime].
   Time(FeelTime),
+
   /// Value representing only the `FEEL` type of value.
   Type(FeelType),
+
   /// **UnaryGreater** value...
   UnaryGreater(Box<Value>),
+
   /// **UnaryGreaterOrEqual** value...
   UnaryGreaterOrEqual(Box<Value>),
+
   /// **UnaryLess** value...
   UnaryLess(Box<Value>),
+
   /// **UnaryLessOrEqual** value...
   UnaryLessOrEqual(Box<Value>),
+
   /// Value for storing years and months duration.
   YearsAndMonthsDuration(FeelYearsAndMonthsDuration),
 }
 
-impl Feelify for Value {
+impl Stringify for Value {
   /// Converts a [Value] to its `TEXT` representation.
+  fn stringify(&self) -> String {
+    self.feelify()
+  }
+}
+
+impl Feelify for Value {
+  /// Converts a [Value] to its `FEEL` representation.
   fn feelify(&self) -> String {
     match self {
       Value::Boolean(b) => format!("{}", b),
@@ -156,7 +196,7 @@ impl Feelify for Value {
       Value::FormalParameter(_, _) => "FormalParameter".to_string(),
       Value::FormalParameters(_) => "FormalParameters".to_string(),
       Value::FunctionBody(_) => "FunctionBody".to_string(),
-      Value::FunctionDefinition(_, _, _) => "FunctionDefinition".to_string(),
+      Value::FunctionDefinition(_, _) => "FunctionDefinition".to_string(),
       Value::IntervalEnd(_, _) => "IntervalEnd".to_string(),
       Value::IntervalStart(_, _) => "IntervalStart".to_string(),
       Value::Irrelevant => "Irrelevant".to_string(),
@@ -234,19 +274,19 @@ impl Value {
       Value::FormalParameter(_, feel_type) => feel_type.clone(),
       Value::FormalParameters(_) => FeelType::Any,
       Value::FunctionBody(_) => FeelType::Any,
-      Value::FunctionDefinition(parameters, _, result_type) => {
+      Value::FunctionDefinition(parameters, _) => {
         let parameter_types = parameters.iter().map(|(_, feel_type)| feel_type.clone()).collect();
-        FeelType::Function(parameter_types, Box::new(result_type.clone()))
+        FeelType::Function(parameter_types, Box::new(FeelType::Any))
       }
       Value::IntervalEnd(interval_end, _) => interval_end.type_of(),
       Value::IntervalStart(interval_start, _) => interval_start.type_of(),
       Value::Irrelevant => FeelType::Any,
       Value::List(values) => {
-        if values.is_empty() {
+        if values.to_vec().is_empty() {
           FeelType::List(Box::new(FeelType::Null))
         } else {
-          let item_type = values.deref()[0].type_of();
-          for item in values.deref() {
+          let item_type = values.to_vec()[0].type_of();
+          for item in values.to_vec() {
             if item.type_of() != item_type {
               return FeelType::List(Box::new(FeelType::Any));
             }
@@ -283,8 +323,8 @@ impl Value {
   pub fn coerce(&self, feel_type: &FeelType) -> Value {
     // coercion of singleton list into single value when single type expected
     if let Value::List(items) = self {
-      if items.len() == 1 && items[0].type_of().is_conformant(feel_type) {
-        return items[0].clone();
+      if items.to_vec().len() == 1 && items.to_vec()[0].type_of().is_conformant(feel_type) {
+        return items.to_vec()[0].clone();
       }
     }
     // coercion of single value into singleton list when expected a list
@@ -357,14 +397,31 @@ impl Value {
 pub struct Values(Vec<Value>);
 
 impl Values {
+  pub fn empty() -> Self {
+    Self(vec![])
+  }
   pub fn new(values: Vec<Value>) -> Self {
     Self(values)
   }
-}
-
-impl Deref for Values {
-  type Target = Vec<Value>;
-  fn deref(&self) -> &Self::Target {
+  pub fn add(&mut self, value: Value) {
+    self.0.push(value);
+  }
+  pub fn insert(&mut self, index: usize, value: Value) {
+    self.0.insert(index, value);
+  }
+  pub fn remove(&mut self, index: usize) {
+    self.0.remove(index);
+  }
+  pub fn len(&self) -> usize {
+    self.0.len()
+  }
+  pub fn is_empty(&self) -> bool {
+    self.0.is_empty()
+  }
+  pub fn reverse(&mut self) {
+    self.0.reverse();
+  }
+  pub fn to_vec(&self) -> &Vec<Value> {
     &self.0
   }
 }
@@ -386,8 +443,7 @@ impl Jsonify for Values {
 /// Definitions of value errors.
 pub mod errors {
   use crate::values::Value;
-  use dmntk_common::errors::DmntkError;
-  use dmntk_common::feelify::Feelify;
+  use dmntk_common::{DmntkError, Feelify};
 
   /// Value errors.
   #[derive(Debug, PartialEq)]
